==> swagger-api__apidom-json-pointer-0.70.0.jar: META-INF/resources/webjars/swagger-api__apidom-json-pointer/0.70.0/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# [0.70.0](https://github.com/swagger-api/apidom/compare/v0.69.3...v0.70.0) (2023-05-23)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.69.3](https://github.com/swagger-api/apidom/compare/v0.69.2...v0.69.3) (2023-04-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.69.2](https://github.com/swagger-api/apidom/compare/v0.69.1...v0.69.2) (2023-04-03)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.69.1](https://github.com/swagger-api/apidom/compare/v0.69.0...v0.69.1) (2023-03-28)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.69.0](https://github.com/swagger-api/apidom/compare/v0.68.1...v0.69.0) (2023-02-28)

### Features

- add support for publishing to npmjs.com ([#2597](https://github.com/swagger-api/apidom/issues/2597)) ([5ac3cd9](https://github.com/swagger-api/apidom/commit/5ac3cd9a83bbe3b4ce2fac732633fb179cd9747f)), closes [#2290](https://github.com/swagger-api/apidom/issues/2290)

## [0.68.1](https://github.com/swagger-api/apidom/compare/v0.68.0...v0.68.1) (2023-02-20)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.68.0](https://github.com/swagger-api/apidom/compare/v0.67.1...v0.68.0) (2023-02-16)

### Features

- **json-pointer:** add sideEffects field to package.json ([85d32e9](https://github.com/swagger-api/apidom/commit/85d32e9d01af4ba9d6598d3f9c4649390b4348f7)), closes [#2566](https://github.com/swagger-api/apidom/issues/2566)

## [0.67.1](https://github.com/swagger-api/apidom/compare/v0.67.0...v0.67.1) (2023-02-15)

### Bug Fixes

- **deps:** relax @babel/runtime-corejs3 version ([#2563](https://github.com/swagger-api/apidom/issues/2563)) ([3523a14](https://github.com/swagger-api/apidom/commit/3523a145a8390bb85139d9a8c3919b0c4ef75962)), closes [#2562](https://github.com/swagger-api/apidom/issues/2562)

# [0.67.0](https://github.com/swagger-api/apidom/compare/v0.66.0...v0.67.0) (2023-02-07)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.66.0](https://github.com/swagger-api/apidom/compare/v0.65.0...v0.66.0) (2023-01-25)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.65.0](https://github.com/swagger-api/apidom/compare/v0.64.0...v0.65.0) (2023-01-20)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.64.0](https://github.com/swagger-api/apidom/compare/v0.63.1...v0.64.0) (2023-01-16)

### Bug Fixes

- **json-pointer:** fix JSON Pointer evaluation for % character ([#2461](https://github.com/swagger-api/apidom/issues/2461)) ([cc7167d](https://github.com/swagger-api/apidom/commit/cc7167d66844fde0b279d0dc063712acb622b615)), closes [/www.rfc-editor.org/rfc/rfc6901#section-5](https://github.com//www.rfc-editor.org/rfc/rfc6901/issues/section-5)

# [0.63.0](https://github.com/swagger-api/apidom/compare/v0.62.1...v0.63.0) (2023-01-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.62.1](https://github.com/swagger-api/apidom/compare/v0.62.0...v0.62.1) (2023-01-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.62.0](https://github.com/swagger-api/apidom/compare/v0.61.0...v0.62.0) (2023-01-03)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.61.0](https://github.com/swagger-api/apidom/compare/v0.60.0...v0.61.0) (2022-12-31)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.60.0](https://github.com/swagger-api/apidom/compare/v0.59.0...v0.60.0) (2022-12-28)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.59.0](https://github.com/swagger-api/apidom/compare/v0.58.0...v0.59.0) (2022-12-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.58.0](https://github.com/swagger-api/apidom/compare/v0.57.0...v0.58.0) (2022-12-16)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.57.0](https://github.com/swagger-api/apidom/compare/v0.56.3...v0.57.0) (2022-12-08)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.56.2](https://github.com/swagger-api/apidom/compare/v0.56.1...v0.56.2) (2022-11-16)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.56.1](https://github.com/swagger-api/apidom/compare/v0.56.0...v0.56.1) (2022-11-11)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.56.0](https://github.com/swagger-api/apidom/compare/v0.55.1...v0.56.0) (2022-11-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.55.0](https://github.com/swagger-api/apidom/compare/v0.54.0...v0.55.0) (2022-11-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.54.0](https://github.com/swagger-api/apidom/compare/v0.53.0...v0.54.0) (2022-10-28)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.53.0](https://github.com/swagger-api/apidom/compare/v0.52.0...v0.53.0) (2022-10-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.52.0](https://github.com/swagger-api/apidom/compare/v0.51.1...v0.52.0) (2022-10-25)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.51.1](https://github.com/swagger-api/apidom/compare/v0.51.0...v0.51.1) (2022-10-21)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.51.0](https://github.com/swagger-api/apidom/compare/v0.50.0...v0.51.0) (2022-10-20)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.50.0](https://github.com/swagger-api/apidom/compare/v0.49.0...v0.50.0) (2022-10-13)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.49.0](https://github.com/swagger-api/apidom/compare/v0.48.0...v0.49.0) (2022-10-11)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.48.0](https://github.com/swagger-api/apidom/compare/v0.47.0...v0.48.0) (2022-10-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.47.0](https://github.com/swagger-api/apidom/compare/v0.46.0...v0.47.0) (2022-09-29)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.46.0](https://github.com/swagger-api/apidom/compare/v0.45.0...v0.46.0) (2022-09-21)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.45.0](https://github.com/swagger-api/apidom/compare/v0.44.0...v0.45.0) (2022-09-13)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.44.0](https://github.com/swagger-api/apidom/compare/v0.43.0...v0.44.0) (2022-09-05)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.43.0](https://github.com/swagger-api/apidom/compare/v0.42.0...v0.43.0) (2022-08-31)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.42.0](https://github.com/swagger-api/apidom/compare/v0.41.1...v0.42.0) (2022-08-30)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.41.0](https://github.com/swagger-api/apidom/compare/v0.40.3...v0.41.0) (2022-08-19)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.40.0](https://github.com/swagger-api/apidom/compare/v0.39.0...v0.40.0) (2022-08-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.39.0](https://github.com/swagger-api/apidom/compare/v0.38.0...v0.39.0) (2022-07-29)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.38.0](https://github.com/swagger-api/apidom/compare/v0.37.0...v0.38.0) (2022-07-29)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.37.0](https://github.com/swagger-api/apidom/compare/v0.36.0...v0.37.0) (2022-07-29)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.36.0](https://github.com/swagger-api/apidom/compare/v0.35.1...v0.36.0) (2022-07-13)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.35.0](https://github.com/swagger-api/apidom/compare/v0.34.0...v0.35.0) (2022-07-05)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.34.0](https://github.com/swagger-api/apidom/compare/v0.33.0...v0.34.0) (2022-07-01)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.33.0](https://github.com/swagger-api/apidom/compare/v0.32.0...v0.33.0) (2022-06-28)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.32.0](https://github.com/swagger-api/apidom/compare/v0.31.2...v0.32.0) (2022-06-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.31.2](https://github.com/swagger-api/apidom/compare/v0.31.1...v0.31.2) (2022-06-24)

### Bug Fixes

- **build:** make using minim an implementation detail ([a45009f](https://github.com/swagger-api/apidom/commit/a45009fef5855f3b2fba699c9e4faf560c613443)), closes [#1632](https://github.com/swagger-api/apidom/issues/1632)

## [0.31.1](https://github.com/swagger-api/apidom/compare/v0.31.0...v0.31.1) (2022-06-23)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.31.0](https://github.com/swagger-api/apidom/compare/v0.30.1...v0.31.0) (2022-06-21)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.30.0](https://github.com/swagger-api/apidom/compare/v0.29.1...v0.30.0) (2022-06-07)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.29.1](https://github.com/swagger-api/apidom/compare/v0.29.0...v0.29.1) (2022-06-03)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.29.0](https://github.com/swagger-api/apidom/compare/v0.28.0...v0.29.0) (2022-05-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.28.0](https://github.com/swagger-api/apidom/compare/v0.27.0...v0.28.0) (2022-05-22)

### Features

- **json-pointer:** add support for JSON Pointer ([#1492](https://github.com/swagger-api/apidom/issues/1492)) ([2b75806](https://github.com/swagger-api/apidom/commit/2b75806964edce80110d2a190a91d7b8ab4c0ff1)), closes [#1491](https://github.com/swagger-api/apidom/issues/1491)

==> swagger-api__apidom-json-pointer-0.74.0.jar: META-INF/resources/webjars/swagger-api__apidom-json-pointer/0.74.0/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# [0.74.0](https://github.com/swagger-api/apidom/compare/v0.73.0...v0.74.0) (2023-07-24)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer





# [0.73.0](https://github.com/swagger-api/apidom/compare/v0.72.0...v0.73.0) (2023-07-18)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer





# [0.72.0](https://github.com/swagger-api/apidom/compare/v0.71.1...v0.72.0) (2023-07-17)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer





# [0.71.0](https://github.com/swagger-api/apidom/compare/v0.70.4...v0.71.0) (2023-07-13)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer





## [0.70.1](https://github.com/swagger-api/apidom/compare/v0.70.0...v0.70.1) (2023-06-15)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.70.0](https://github.com/swagger-api/apidom/compare/v0.69.3...v0.70.0) (2023-05-23)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.69.3](https://github.com/swagger-api/apidom/compare/v0.69.2...v0.69.3) (2023-04-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.69.2](https://github.com/swagger-api/apidom/compare/v0.69.1...v0.69.2) (2023-04-03)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.69.1](https://github.com/swagger-api/apidom/compare/v0.69.0...v0.69.1) (2023-03-28)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.69.0](https://github.com/swagger-api/apidom/compare/v0.68.1...v0.69.0) (2023-02-28)

### Features

- add support for publishing to npmjs.com ([#2597](https://github.com/swagger-api/apidom/issues/2597)) ([5ac3cd9](https://github.com/swagger-api/apidom/commit/5ac3cd9a83bbe3b4ce2fac732633fb179cd9747f)), closes [#2290](https://github.com/swagger-api/apidom/issues/2290)

## [0.68.1](https://github.com/swagger-api/apidom/compare/v0.68.0...v0.68.1) (2023-02-20)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.68.0](https://github.com/swagger-api/apidom/compare/v0.67.1...v0.68.0) (2023-02-16)

### Features

- **json-pointer:** add sideEffects field to package.json ([85d32e9](https://github.com/swagger-api/apidom/commit/85d32e9d01af4ba9d6598d3f9c4649390b4348f7)), closes [#2566](https://github.com/swagger-api/apidom/issues/2566)

## [0.67.1](https://github.com/swagger-api/apidom/compare/v0.67.0...v0.67.1) (2023-02-15)

### Bug Fixes

- **deps:** relax @babel/runtime-corejs3 version ([#2563](https://github.com/swagger-api/apidom/issues/2563)) ([3523a14](https://github.com/swagger-api/apidom/commit/3523a145a8390bb85139d9a8c3919b0c4ef75962)), closes [#2562](https://github.com/swagger-api/apidom/issues/2562)

# [0.67.0](https://github.com/swagger-api/apidom/compare/v0.66.0...v0.67.0) (2023-02-07)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.66.0](https://github.com/swagger-api/apidom/compare/v0.65.0...v0.66.0) (2023-01-25)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.65.0](https://github.com/swagger-api/apidom/compare/v0.64.0...v0.65.0) (2023-01-20)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.64.0](https://github.com/swagger-api/apidom/compare/v0.63.1...v0.64.0) (2023-01-16)

### Bug Fixes

- **json-pointer:** fix JSON Pointer evaluation for % character ([#2461](https://github.com/swagger-api/apidom/issues/2461)) ([cc7167d](https://github.com/swagger-api/apidom/commit/cc7167d66844fde0b279d0dc063712acb622b615)), closes [/www.rfc-editor.org/rfc/rfc6901#section-5](https://github.com//www.rfc-editor.org/rfc/rfc6901/issues/section-5)

# [0.63.0](https://github.com/swagger-api/apidom/compare/v0.62.1...v0.63.0) (2023-01-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.62.1](https://github.com/swagger-api/apidom/compare/v0.62.0...v0.62.1) (2023-01-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.62.0](https://github.com/swagger-api/apidom/compare/v0.61.0...v0.62.0) (2023-01-03)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.61.0](https://github.com/swagger-api/apidom/compare/v0.60.0...v0.61.0) (2022-12-31)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.60.0](https://github.com/swagger-api/apidom/compare/v0.59.0...v0.60.0) (2022-12-28)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.59.0](https://github.com/swagger-api/apidom/compare/v0.58.0...v0.59.0) (2022-12-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.58.0](https://github.com/swagger-api/apidom/compare/v0.57.0...v0.58.0) (2022-12-16)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.57.0](https://github.com/swagger-api/apidom/compare/v0.56.3...v0.57.0) (2022-12-08)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.56.2](https://github.com/swagger-api/apidom/compare/v0.56.1...v0.56.2) (2022-11-16)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.56.1](https://github.com/swagger-api/apidom/compare/v0.56.0...v0.56.1) (2022-11-11)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.56.0](https://github.com/swagger-api/apidom/compare/v0.55.1...v0.56.0) (2022-11-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.55.0](https://github.com/swagger-api/apidom/compare/v0.54.0...v0.55.0) (2022-11-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.54.0](https://github.com/swagger-api/apidom/compare/v0.53.0...v0.54.0) (2022-10-28)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.53.0](https://github.com/swagger-api/apidom/compare/v0.52.0...v0.53.0) (2022-10-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.52.0](https://github.com/swagger-api/apidom/compare/v0.51.1...v0.52.0) (2022-10-25)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.51.1](https://github.com/swagger-api/apidom/compare/v0.51.0...v0.51.1) (2022-10-21)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.51.0](https://github.com/swagger-api/apidom/compare/v0.50.0...v0.51.0) (2022-10-20)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.50.0](https://github.com/swagger-api/apidom/compare/v0.49.0...v0.50.0) (2022-10-13)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.49.0](https://github.com/swagger-api/apidom/compare/v0.48.0...v0.49.0) (2022-10-11)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.48.0](https://github.com/swagger-api/apidom/compare/v0.47.0...v0.48.0) (2022-10-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.47.0](https://github.com/swagger-api/apidom/compare/v0.46.0...v0.47.0) (2022-09-29)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.46.0](https://github.com/swagger-api/apidom/compare/v0.45.0...v0.46.0) (2022-09-21)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.45.0](https://github.com/swagger-api/apidom/compare/v0.44.0...v0.45.0) (2022-09-13)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.44.0](https://github.com/swagger-api/apidom/compare/v0.43.0...v0.44.0) (2022-09-05)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.43.0](https://github.com/swagger-api/apidom/compare/v0.42.0...v0.43.0) (2022-08-31)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.42.0](https://github.com/swagger-api/apidom/compare/v0.41.1...v0.42.0) (2022-08-30)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.41.0](https://github.com/swagger-api/apidom/compare/v0.40.3...v0.41.0) (2022-08-19)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.40.0](https://github.com/swagger-api/apidom/compare/v0.39.0...v0.40.0) (2022-08-04)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.39.0](https://github.com/swagger-api/apidom/compare/v0.38.0...v0.39.0) (2022-07-29)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.38.0](https://github.com/swagger-api/apidom/compare/v0.37.0...v0.38.0) (2022-07-29)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.37.0](https://github.com/swagger-api/apidom/compare/v0.36.0...v0.37.0) (2022-07-29)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.36.0](https://github.com/swagger-api/apidom/compare/v0.35.1...v0.36.0) (2022-07-13)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.35.0](https://github.com/swagger-api/apidom/compare/v0.34.0...v0.35.0) (2022-07-05)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.34.0](https://github.com/swagger-api/apidom/compare/v0.33.0...v0.34.0) (2022-07-01)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.33.0](https://github.com/swagger-api/apidom/compare/v0.32.0...v0.33.0) (2022-06-28)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.32.0](https://github.com/swagger-api/apidom/compare/v0.31.2...v0.32.0) (2022-06-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.31.2](https://github.com/swagger-api/apidom/compare/v0.31.1...v0.31.2) (2022-06-24)

### Bug Fixes

- **build:** make using minim an implementation detail ([a45009f](https://github.com/swagger-api/apidom/commit/a45009fef5855f3b2fba699c9e4faf560c613443)), closes [#1632](https://github.com/swagger-api/apidom/issues/1632)

## [0.31.1](https://github.com/swagger-api/apidom/compare/v0.31.0...v0.31.1) (2022-06-23)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.31.0](https://github.com/swagger-api/apidom/compare/v0.30.1...v0.31.0) (2022-06-21)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.30.0](https://github.com/swagger-api/apidom/compare/v0.29.1...v0.30.0) (2022-06-07)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

## [0.29.1](https://github.com/swagger-api/apidom/compare/v0.29.0...v0.29.1) (2022-06-03)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.29.0](https://github.com/swagger-api/apidom/compare/v0.28.0...v0.29.0) (2022-05-27)

**Note:** Version bump only for package @swagger-api/apidom-json-pointer

# [0.28.0](https://github.com/swagger-api/apidom/compare/v0.27.0...v0.28.0) (2022-05-22)

### Features

- **json-pointer:** add support for JSON Pointer ([#1492](https://github.com/swagger-api/apidom/issues/1492)) ([2b75806](https://github.com/swagger-api/apidom/commit/2b75806964edce80110d2a190a91d7b8ab4c0ff1)), closes [#1491](https://github.com/swagger-api/apidom/issues/1491)
